@@ -32,7 +32,6 @@
 #include <stdlib.h>
 #include <sys/types.h>
 #include <sys/ipc.h>
-#include <sys/shm.h>
 #include <sys/time.h>
 #include <unistd.h>
 #include <string.h>
@@ -44,13 +43,16 @@
 #include <X11/Xatom.h>
 #include <X11/extensions/XI.h>
 #include <X11/extensions/XInput.h>
-#include "synaptics.h"
 #include "synaptics-properties.h"
 
 #ifndef XATOM_FLOAT
 #define XATOM_FLOAT "FLOAT"
 #endif
 
+#define SYN_MAX_BUTTONS 12
+#define SBR_MIN 10
+#define SBR_MAX 1000
+
 union flong {                   /* Xlibs 64-bit property handling madness */
     long l;
     float f;
@@ -63,11 +65,11 @@ enum ParaType {
 };
 
 struct Parameter {
-    char *name;                 /* Name of parameter */
+    const char *name;           /* Name of parameter */
     enum ParaType type;         /* Type of parameter */
     double min_val;             /* Minimum allowed value */
     double max_val;             /* Maximum allowed value */
-    char *prop_name;            /* Property name */
+    const char *prop_name;      /* Property name */
     int prop_format;            /* Property format (0 for floats) */
     int prop_offset;            /* Offset inside property */
 };
@@ -79,13 +81,11 @@ static struct Parameter params[] = {
     {"BottomEdge",            PT_INT,    0, 10000, SYNAPTICS_PROP_EDGES,	32,	3},
     {"FingerLow",             PT_INT,    0, 255,   SYNAPTICS_PROP_FINGER,	32,	0},
     {"FingerHigh",            PT_INT,    0, 255,   SYNAPTICS_PROP_FINGER,	32,	1},
-    {"FingerPress",           PT_INT,    0, 256,   SYNAPTICS_PROP_FINGER,	32,	2},
     {"MaxTapTime",            PT_INT,    0, 1000,  SYNAPTICS_PROP_TAP_TIME,	32,	0},
     {"MaxTapMove",            PT_INT,    0, 2000,  SYNAPTICS_PROP_TAP_MOVE,	32,	0},
     {"MaxDoubleTapTime",      PT_INT,    0, 1000,  SYNAPTICS_PROP_TAP_DURATIONS,32,	1},
     {"SingleTapTimeout",      PT_INT,    0, 1000,  SYNAPTICS_PROP_TAP_DURATIONS,32,	0},
     {"ClickTime",             PT_INT,    0, 1000,  SYNAPTICS_PROP_TAP_DURATIONS,32,	2},
-    {"FastTaps",              PT_BOOL,   0, 1,     SYNAPTICS_PROP_TAP_FAST,	8,	0},
     {"EmulateMidButtonTime",  PT_INT,    0, 1000,  SYNAPTICS_PROP_MIDDLE_TIMEOUT,32,	0},
     {"EmulateTwoFingerMinZ",  PT_INT,    0, 1000,  SYNAPTICS_PROP_TWOFINGER_PRESSURE,	32,	0},
     {"EmulateTwoFingerMinW",  PT_INT,    0, 15,    SYNAPTICS_PROP_TWOFINGER_WIDTH,	32,	0},
@@ -99,12 +99,6 @@ static struct Parameter params[] = {
     {"MinSpeed",              PT_DOUBLE, 0, 255.0,   SYNAPTICS_PROP_SPEED,	0, /*float */	0},
     {"MaxSpeed",              PT_DOUBLE, 0, 255.0,   SYNAPTICS_PROP_SPEED,	0, /*float */	1},
     {"AccelFactor",           PT_DOUBLE, 0, 1.0,   SYNAPTICS_PROP_SPEED,	0, /*float */	2},
-    {"TrackstickSpeed",       PT_DOUBLE, 0, 200.0, SYNAPTICS_PROP_SPEED,	0, /*float */ 3},
-    {"EdgeMotionMinZ",        PT_INT,    1, 255,   SYNAPTICS_PROP_EDGEMOTION_PRESSURE,  32,	0},
-    {"EdgeMotionMaxZ",        PT_INT,    1, 255,   SYNAPTICS_PROP_EDGEMOTION_PRESSURE,  32,	1},
-    {"EdgeMotionMinSpeed",    PT_INT,    0, 1000,  SYNAPTICS_PROP_EDGEMOTION_SPEED,     32,	0},
-    {"EdgeMotionMaxSpeed",    PT_INT,    0, 1000,  SYNAPTICS_PROP_EDGEMOTION_SPEED,     32,	1},
-    {"EdgeMotionUseAlways",   PT_BOOL,   0, 1,     SYNAPTICS_PROP_EDGEMOTION,   8,	0},
     {"UpDownScrolling",       PT_BOOL,   0, 1,     SYNAPTICS_PROP_BUTTONSCROLLING,  8,	0},
     {"LeftRightScrolling",    PT_BOOL,   0, 1,     SYNAPTICS_PROP_BUTTONSCROLLING,  8,	1},
     {"UpDownScrollRepeat",    PT_BOOL,   0, 1,     SYNAPTICS_PROP_BUTTONSCROLLING_REPEAT,   8,	0},
@@ -138,10 +132,10 @@ static struct Parameter params[] = {
     {"PressureMotionMaxFactor", PT_DOUBLE, 0, 10.0,SYNAPTICS_PROP_PRESSURE_MOTION_FACTOR,	0 /*float*/,	1},
     {"GrabEventDevice",       PT_BOOL,   0, 1,     SYNAPTICS_PROP_GRAB,	8,	0},
     {"TapAndDragGesture",     PT_BOOL,   0, 1,     SYNAPTICS_PROP_GESTURES,	8,	0},
-    {"AreaLeftEdge",          PT_INT,    0, 10000, SYNAPTICS_PROP_AREA,	32,	0},
-    {"AreaRightEdge",         PT_INT,    0, 10000, SYNAPTICS_PROP_AREA,	32,	1},
-    {"AreaTopEdge",           PT_INT,    0, 10000, SYNAPTICS_PROP_AREA,	32,	2},
-    {"AreaBottomEdge",        PT_INT,    0, 10000, SYNAPTICS_PROP_AREA,	32,	3},
+    {"AreaLeftEdge",          PT_INT, INT_MIN, INT_MAX, SYNAPTICS_PROP_AREA,	32,	0},
+    {"AreaRightEdge",         PT_INT, INT_MIN, INT_MAX, SYNAPTICS_PROP_AREA,	32,	1},
+    {"AreaTopEdge",           PT_INT, INT_MIN, INT_MAX, SYNAPTICS_PROP_AREA,	32,	2},
+    {"AreaBottomEdge",        PT_INT, INT_MIN, INT_MAX, SYNAPTICS_PROP_AREA,	32,	3},
     {"HorizHysteresis",       PT_INT,    0, 10000, SYNAPTICS_PROP_NOISE_CANCELLATION, 32,	0},
     {"VertHysteresis",        PT_INT,    0, 10000, SYNAPTICS_PROP_NOISE_CANCELLATION, 32,	1},
     {"ClickPad",              PT_BOOL,   0, 1,     SYNAPTICS_PROP_CLICKPAD,	8,	0},
@@ -197,111 +191,9 @@ parse_cmd(char *cmd, struct Parameter **par)
     return 0;
 }
 
-static int
-is_equal(SynapticsSHM * s1, SynapticsSHM * s2)
-{
-    int i;
-
-    if ((s1->x != s2->x) ||
-        (s1->y != s2->y) ||
-        (s1->z != s2->z) ||
-        (s1->numFingers != s2->numFingers) ||
-        (s1->fingerWidth != s2->fingerWidth) ||
-        (s1->left != s2->left) ||
-        (s1->right != s2->right) ||
-        (s1->up != s2->up) ||
-        (s1->down != s2->down) || (s1->middle != s2->middle))
-        return 0;
-
-    for (i = 0; i < 8; i++)
-        if (s1->multi[i] != s2->multi[i])
-            return 0;
-
-    return 1;
-}
-
-static double
-get_time(void)
-{
-    struct timeval tv;
-
-    gettimeofday(&tv, NULL);
-    return tv.tv_sec + tv.tv_usec / 1000000.0;
-}
-
-static void
-shm_monitor(SynapticsSHM * synshm, int delay)
-{
-    int header = 0;
-    SynapticsSHM old;
-    double t0 = get_time();
-
-    memset(&old, 0, sizeof(SynapticsSHM));
-    old.x = -1;                 /* Force first equality test to fail */
-
-    while (1) {
-        SynapticsSHM cur = *synshm;
-
-        if (!is_equal(&old, &cur)) {
-            if (!header) {
-                printf("%8s  %4s %4s %3s %s %2s %2s %s %s %s %s  %8s  "
-                       "%2s %2s %2s %3s %3s\n",
-                       "time", "x", "y", "z", "f", "w", "l", "r", "u", "d", "m",
-                       "multi", "gl", "gm", "gr", "gdx", "gdy");
-                header = 20;
-            }
-            header--;
-            printf
-                ("%8.3f  %4d %4d %3d %d %2d %2d %d %d %d %d  %d%d%d%d%d%d%d%d\n",
-                 get_time() - t0, cur.x, cur.y, cur.z, cur.numFingers,
-                 cur.fingerWidth, cur.left, cur.right, cur.up, cur.down,
-                 cur.middle, cur.multi[0], cur.multi[1], cur.multi[2],
-                 cur.multi[3], cur.multi[4], cur.multi[5], cur.multi[6],
-                 cur.multi[7]);
-            fflush(stdout);
-            old = cur;
-        }
-        usleep(delay * 1000);
-    }
-}
-
-/** Init and return SHM area or NULL on error */
-static SynapticsSHM *
-shm_init()
-{
-    SynapticsSHM *synshm = NULL;
-    int shmid = 0;
-
-    if ((shmid = shmget(SHM_SYNAPTICS, sizeof(SynapticsSHM), 0)) == -1) {
-        if ((shmid = shmget(SHM_SYNAPTICS, 0, 0)) == -1)
-            fprintf(stderr,
-                    "Can't access shared memory area. SHMConfig disabled?\n");
-        else
-            fprintf(stderr,
-                    "Incorrect size of shared memory area. Incompatible driver version?\n");
-    }
-    else if ((synshm = (SynapticsSHM *) shmat(shmid, NULL, SHM_RDONLY)) == NULL)
-        perror("shmat");
-
-    return synshm;
-}
-
-static void
-shm_process_commands(int do_monitor, int delay)
-{
-    SynapticsSHM *synshm = NULL;
-
-    synshm = shm_init();
-    if (!synshm)
-        return;
-
-    if (do_monitor)
-        shm_monitor(synshm, delay);
-}
-
 /** Init display connection or NULL on error */
 static Display *
-dp_init()
+dp_init(void)
 {
     Display *dpy = NULL;
     XExtensionVersion *v = NULL;
@@ -576,11 +468,7 @@ dp_show_settings(Display * dpy, XDevice * dev)
 static void
 usage(void)
 {
-    fprintf(stderr,
-            "Usage: synclient [-s] [-m interval] [-h] [-l] [-V] [-?] [var1=value1 [var2=value2] ...]\n");
-    fprintf(stderr,
-            "  -m monitor changes to the touchpad state (implies -s)\n"
-            "     interval specifies how often (in ms) to poll the touchpad state\n");
+    fprintf(stderr, "Usage: synclient [-h] [-l] [-V] [-?] [var1=value1 [var2=value2] ...]\n");
     fprintf(stderr, "  -l List current user settings\n");
     fprintf(stderr, "  -V Print synclient version string and exit\n");
     fprintf(stderr, "  -? Show this help message\n");
@@ -592,8 +480,6 @@ int
 main(int argc, char *argv[])
 {
     int c;
-    int delay = -1;
-    int do_monitor = 0;
     int dump_settings = 0;
     int first_cmd;
 
@@ -604,32 +490,24 @@ main(int argc, char *argv[])
         dump_settings = 1;
 
     /* Parse command line parameters */
-    while ((c = getopt(argc, argv, "sm:hlV")) != -1) {
+    while ((c = getopt(argc, argv, "lV?")) != -1) {
         switch (c) {
-        case 'm':
-            do_monitor = 1;
-            if ((delay = atoi(optarg)) < 0)
-                usage();
-            break;
         case 'l':
             dump_settings = 1;
             break;
         case 'V':
             printf("%s\n", VERSION);
             exit(0);
+        case '?':
         default:
             usage();
         }
     }
 
     first_cmd = optind;
-    if (!do_monitor && !dump_settings && first_cmd == argc)
+    if (!dump_settings && first_cmd == argc)
         usage();
 
-    /* Connect to the shared memory area */
-    if (do_monitor)
-        shm_process_commands(do_monitor, delay);
-
     dpy = dp_init();
     if (!dpy || !(dev = dp_get_device(dpy)))
         return 1;
